@@ -1,8 +1,10 @@
 #!/bin/sh
 
 # Path to (cross-platform) mingw compiler
-MINGWPATH=/home/tim/bin/mingw/bin
-QTPATH=/home/tim/bin/qt-4.4.0
+#MINGWPATH=/home/tim/bin/mingw/bin
+#QTPATH=/home/tim/bin/qt-4.6.0/qt/
+MINGWPATH=/usr/toolchains/windows-x86-mingw/bin
+QMAKE=i686-pc-mingw32-qmake
 
 BUILDDIR="build.win32"
 
@@ -17,4 +19,4 @@ cd "$BUILDDIR"
 
 # Compile it
 export PATH=$MINGWPATH:$PATH
-$QTPATH/bin/qmake -r -spec win32-mingw-g++ && make || exit 1
+$QMAKE -r -spec win32-g++ "CONFIG += release" && make -j4  || exit 1
